@@ -47,14 +47,14 @@ class Query(object):
         self.get_first() # initial columns and row count
 
         # fetch first page
-        result = self.request.post(gen_sql_result_payload(self.id, self.limit, self.limit * page)).get(
+        result = self.request.post(gen_sql_result_payload(self.id, self.limit, self.limit * (page - 1))).get(
             'sqlResultPagination')
         data = result['result']
 
         while (page - 1) * self.limit + index < self.row_count:
             if index == self.limit:
                 # fetch new page
-                result = self.request.post(gen_sql_result_payload(self.id, self.limit, self.limit * page)).get('sqlResultPagination')
+                result = self.request.post(gen_sql_result_payload(self.id, self.limit, self.limit * (page - 1))).get('sqlResultPagination')
                 data = result['result']
                 index = 0
                 page += 1
@@ -62,6 +62,8 @@ class Query(object):
                 rtn_data = data_factory(data_format=self.data_format, columns=self.columns, data=[data[index]])
                 yield rtn_data
                 index += 1
+            else:
+                break
 
 
     @property
